projectal.dynamic_enums.company_types API documentation

# projectal.dynamic_enums.company_types

View Source

    1from projectal.dynamic_enum import DynamicEnum
    2
    3
    4class CompanyTypes(DynamicEnum):
    5    _name = "CompanyTypeEnum"

class CompanyTypes(projectal.dynamic_enum.DynamicEnum): View Source

    5class CompanyTypes(DynamicEnum):
    6    _name = "CompanyTypeEnum"

##### Inherited Members

projectal.dynamic_enum.DynamicEnum
  get
  set